==> ejc-salary-impl-3.0.0-20241129.064655-72-sources.jar: com/ejianc/business/salary/bean/RosterSocialSecurityEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 人员花名册-社保
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_roster_social_security")
public class RosterSocialSecurityEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="payment_base")
    private BigDecimal paymentBase; // 缴费基数
    @TableField(value="start_time")
    private Date startTime; // 社保执行时间
    @TableField(value="end_time")
    private Date endTime; // 社保结束时间
    @TableField(value="person_annuity_money")
    private BigDecimal personAnnuityMoney; // 个人养老金
    @TableField(value="company_annuity_money")
    private BigDecimal companyAnnuityMoney; // 公司养老金
    @TableField(value="person_medical_money")
    private BigDecimal personMedicalMoney; // 个人医疗金额
    @TableField(value="company_medical_money")
    private BigDecimal companyMedicalMoney; // 公司医疗金额
    @TableField(value="person_unemployment_money")
    private BigDecimal personUnemploymentMoney; // 个人失业金额
    @TableField(value="company_unemployment_money")
    private BigDecimal companyUnemploymentMoney; // 公司失业金额
    @TableField(value="company_childbirth_money")
    private BigDecimal companyChildbirthMoney; // 公司生育金额
    @TableField(value="company_injury_money")
    private BigDecimal companyInjuryMoney; // 公司工伤金额
    @TableField(value="change_reason")
    private String changeReason; // 变更原因
    @TableField(value="data_state")
    private String dataState; // 状态
    @TableField(value="employee_code")
    private String employeeCode; // 员工编码
    @TableField(value="id_card")
    private String idCard; // 身份证号
    
    
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public BigDecimal getPaymentBase() {
        return paymentBase;
    }

    public void setPaymentBase(BigDecimal paymentBase) {
        this.paymentBase = paymentBase;
    }
    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }
    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
    public BigDecimal getPersonAnnuityMoney() {
        return personAnnuityMoney;
    }

    public void setPersonAnnuityMoney(BigDecimal personAnnuityMoney) {
        this.personAnnuityMoney = personAnnuityMoney;
    }
    public BigDecimal getCompanyAnnuityMoney() {
        return companyAnnuityMoney;
    }

    public void setCompanyAnnuityMoney(BigDecimal companyAnnuityMoney) {
        this.companyAnnuityMoney = companyAnnuityMoney;
    }
    public BigDecimal getPersonMedicalMoney() {
        return personMedicalMoney;
    }

    public void setPersonMedicalMoney(BigDecimal personMedicalMoney) {
        this.personMedicalMoney = personMedicalMoney;
    }
    public BigDecimal getCompanyMedicalMoney() {
        return companyMedicalMoney;
    }

    public void setCompanyMedicalMoney(BigDecimal companyMedicalMoney) {
        this.companyMedicalMoney = companyMedicalMoney;
    }
    public BigDecimal getPersonUnemploymentMoney() {
        return personUnemploymentMoney;
    }

    public void setPersonUnemploymentMoney(BigDecimal personUnemploymentMoney) {
        this.personUnemploymentMoney = personUnemploymentMoney;
    }
    public BigDecimal getCompanyUnemploymentMoney() {
        return companyUnemploymentMoney;
    }

    public void setCompanyUnemploymentMoney(BigDecimal companyUnemploymentMoney) {
        this.companyUnemploymentMoney = companyUnemploymentMoney;
    }
    public BigDecimal getCompanyChildbirthMoney() {
        return companyChildbirthMoney;
    }

    public void setCompanyChildbirthMoney(BigDecimal companyChildbirthMoney) {
        this.companyChildbirthMoney = companyChildbirthMoney;
    }
    public BigDecimal getCompanyInjuryMoney() {
        return companyInjuryMoney;
    }

    public void setCompanyInjuryMoney(BigDecimal companyInjuryMoney) {
        this.companyInjuryMoney = companyInjuryMoney;
    }
    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }
    public String getDataState() {
        return dataState;
    }

    public void setDataState(String dataState) {
        this.dataState = dataState;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    
}

==> ejc-salary-impl-3.0.0-20250820.033922-165-sources.jar: com/ejianc/business/salary/bean/RosterSocialSecurityEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 人员花名册-社保
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_roster_social_security")
public class RosterSocialSecurityEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="payment_base")
    private BigDecimal paymentBase; // 缴费基数
    @TableField(value="start_time")
    private Date startTime; // 社保执行时间
    @TableField(value="end_time")
    private Date endTime; // 社保结束时间
    @TableField(value="person_annuity_money")
    private BigDecimal personAnnuityMoney; // 个人养老金
    @TableField(value="company_annuity_money")
    private BigDecimal companyAnnuityMoney; // 公司养老金
    @TableField(value="person_medical_money")
    private BigDecimal personMedicalMoney; // 个人医疗金额
    @TableField(value="company_medical_money")
    private BigDecimal companyMedicalMoney; // 公司医疗金额
    @TableField(value="person_unemployment_money")
    private BigDecimal personUnemploymentMoney; // 个人失业金额
    @TableField(value="company_unemployment_money")
    private BigDecimal companyUnemploymentMoney; // 公司失业金额
    @TableField(value="company_childbirth_money")
    private BigDecimal companyChildbirthMoney; // 公司生育金额
    @TableField(value="company_injury_money")
    private BigDecimal companyInjuryMoney; // 公司工伤金额
    @TableField(value="change_reason")
    private String changeReason; // 变更原因
    @TableField(value="data_state")
    private String dataState; // 状态
    @TableField(value="employee_code")
    private String employeeCode; // 员工编码
    @TableField(value="id_card")
    private String idCard; // 身份证号
    @TableField(value="critical_illness_mny")
    private BigDecimal criticalIllnessMny; // 大病医保

    public BigDecimal getCriticalIllnessMny() {
        return criticalIllnessMny;
    }

    public void setCriticalIllnessMny(BigDecimal criticalIllnessMny) {
        this.criticalIllnessMny = criticalIllnessMny;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public BigDecimal getPaymentBase() {
        return paymentBase;
    }

    public void setPaymentBase(BigDecimal paymentBase) {
        this.paymentBase = paymentBase;
    }
    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }
    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
    public BigDecimal getPersonAnnuityMoney() {
        return personAnnuityMoney;
    }

    public void setPersonAnnuityMoney(BigDecimal personAnnuityMoney) {
        this.personAnnuityMoney = personAnnuityMoney;
    }
    public BigDecimal getCompanyAnnuityMoney() {
        return companyAnnuityMoney;
    }

    public void setCompanyAnnuityMoney(BigDecimal companyAnnuityMoney) {
        this.companyAnnuityMoney = companyAnnuityMoney;
    }
    public BigDecimal getPersonMedicalMoney() {
        return personMedicalMoney;
    }

    public void setPersonMedicalMoney(BigDecimal personMedicalMoney) {
        this.personMedicalMoney = personMedicalMoney;
    }
    public BigDecimal getCompanyMedicalMoney() {
        return companyMedicalMoney;
    }

    public void setCompanyMedicalMoney(BigDecimal companyMedicalMoney) {
        this.companyMedicalMoney = companyMedicalMoney;
    }
    public BigDecimal getPersonUnemploymentMoney() {
        return personUnemploymentMoney;
    }

    public void setPersonUnemploymentMoney(BigDecimal personUnemploymentMoney) {
        this.personUnemploymentMoney = personUnemploymentMoney;
    }
    public BigDecimal getCompanyUnemploymentMoney() {
        return companyUnemploymentMoney;
    }

    public void setCompanyUnemploymentMoney(BigDecimal companyUnemploymentMoney) {
        this.companyUnemploymentMoney = companyUnemploymentMoney;
    }
    public BigDecimal getCompanyChildbirthMoney() {
        return companyChildbirthMoney;
    }

    public void setCompanyChildbirthMoney(BigDecimal companyChildbirthMoney) {
        this.companyChildbirthMoney = companyChildbirthMoney;
    }
    public BigDecimal getCompanyInjuryMoney() {
        return companyInjuryMoney;
    }

    public void setCompanyInjuryMoney(BigDecimal companyInjuryMoney) {
        this.companyInjuryMoney = companyInjuryMoney;
    }
    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }
    public String getDataState() {
        return dataState;
    }

    public void setDataState(String dataState) {
        this.dataState = dataState;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    
}
